def promax(x):
    print(x**x)
def teamlag(x):
    if x == "lag":
        print("Team Lag is OP")


if __name__ == '__main__':
    def critic(x):
        if x == 1:
            print("Working fine")
        else:
            print("Fucked up")
    